@@ -1,5 +1,5 @@
 package Amazon::DynamoDB::20120810;
-$Amazon::DynamoDB::20120810::VERSION = '0.33';
+$Amazon::DynamoDB::20120810::VERSION = '0.34';
 use strict;
 use warnings;
 
@@ -215,25 +215,36 @@ method put_item (ConditionalOperatorType :$ConditionalOperator,
 
 
 
-method update_item (AttributeUpdatesType :$AttributeUpdates!,
+method update_item (AttributeUpdatesType :$AttributeUpdates,
+                    Str :$ConditionExpression,
                     ConditionalOperatorType :$ConditionalOperator,
                     ExpectedType :$Expected,
                     KeyType :$Key!,
                     ReturnConsumedCapacityType :$ReturnConsumedCapacity,
                     ReturnItemCollectionMetricsType :$ReturnItemCollectionMetrics,
                     ReturnValuesType :$ReturnValues,
-                    TableNameType :$TableName!) {
+                    TableNameType :$TableName!,
+                    ExpressionAttributeValuesType :$ExpressionAttributeValues,
+                    ExpressionAttributeNamesType :$ExpressionAttributeNames,
+                    Str :$UpdateExpression,
+                ) {
+    (defined($AttributeUpdates) xor defined($UpdateExpression)) || die("Either AttributeUpdates or UpdateExpression is required");
+    
     my $req = $self->make_request(
         target => 'UpdateItem',
         payload => _make_payload({
                                  'AttributeUpdates' => $AttributeUpdates,
                                  'ConditionalOperator' => $ConditionalOperator,
+                                 'ConditionExpression' => $ConditionExpression,
                                  'Expected' => $Expected,
+                                 'ExpressionAttributeNames' => $ExpressionAttributeNames,
+                                 'ExpressionAttributeValues' => $ExpressionAttributeValues,
                                  'Key' => $Key,
                                  'ReturnConsumedCapacity' => $ReturnConsumedCapacity,
                                  'ReturnItemCollectionMetrics' => $ReturnItemCollectionMetrics,
                                  'ReturnValues' => $ReturnValues,
-                                 'TableName' => $TableName
+                                 'TableName' => $TableName,
+                                 'UpdateExpression' => $UpdateExpression,
                                  }));
     $self->_process_request($req, \&_decode_single_item_change_response);
 }
@@ -926,6 +937,7 @@ my $parameter_type_definitions = {
     TotalSegments => {
         type_check => 'integer',
     },
+    UpdateExpression => {},
 };
 
 
@@ -943,6 +955,9 @@ sub _make_payload {
     my %r;
     foreach my $field_name (@field_names) {
         my $value = $args->{$field_name};
+        if (!defined($value)) {
+            next;
+        }
         my $def = $parameter_type_definitions->{$field_name} || Carp::confess("Unknown parameter type: $field_name");
         if (defined($value)) {
             if ($def->{type_check} && $def->{type_check} eq 'integer') {
@@ -1009,7 +1024,7 @@ Amazon::DynamoDB::20120810
 
 =head1 VERSION
 
-version 0.33
+version 0.34
 
 =head1 DESCRIPTION
 
